/*
 * Copyright 2012 Stefan Haun, Andreas Nürnberger
 * 
 *      Data and Knowledge Engineering Group, 
 * 		Faculty of Computer Science,
 *		Otto-von-Guericke University,
 *		Magdeburg, Germany
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.ovgu.dke.mocca.daemon;

import java.util.Collection;

import de.ovgu.dke.mocca.api.MoccaException;
import de.ovgu.dke.mocca.api.MoccaRuntime;
import de.ovgu.dke.mocca.api.command.CommandHandler;

/**
 * A MOCCA Agent is a collection of Command Handlers with a name, that can be
 * managed by a MOCCA Daemon.
 * 
 * @author Stefan Haun (stefan.haun@ovgu.de)
 * 
 */
public interface MoccaAgent {
	/**
	 * Get the name of this agent.
	 * 
	 * @return A descriptive name.
	 */
	public String getName();

	/**
	 * Get the handlers available for this agent.
	 * 
	 * @return A {@link Collection} of {@link CommandHandler}S supported by this
	 *         agent.
	 */
	public Collection<CommandHandler> getCommandHandlers();

	/**
	 * This method is called when the agent is initialized, i.e. before first
	 * usage, and allows to do some initial setup (based on the provided mocca
	 * runtime) before the handlers are called.
	 * 
	 * @param runtime
	 *            The MOCCA runtime used by the daemon.
	 * @throws NullPointerException
	 *             (optional) if the runtime argument is null.
	 * @throws MoccaException
	 *             if initialization fails. As a consequence the daemon will not
	 *             start.
	 */
	public void init(MoccaRuntime runtime) throws MoccaException;

	/**
	 * This method is called before an agent is discarded and allows to do some
	 * final clean-up.
	 */
	public void destroy();
}
